## 1.4.3.3 (2023-03-13)

appdirs: improve annotation for appauthor argument (#9876)

Fix: Missing annotation for appauthor argument

According to the appdirs doc string and code [1], the appauthor argument in all functions supports False as argument value to skip insertion of author directories.

[1] https://github.com/ActiveState/appdirs/blob/master/appdirs.py#L52

## 1.4.3.2 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.4.3.1 (2022-11-16)

Always use `bool` and `Literal` for Python compat code (#9213)

## 1.4.3 (2022-06-25)

appdirs, tabulate, termcolor, xmltodict: check missing defs (#8156)

complete termcolor, xmltodict

## 1.4.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 1.4.0 (2021-09-20)

Create stubs for appdirs (#6047)

